@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-12-09'; # DATE
+our $DATE = '2021-12-11'; # DATE
 our $DIST = 'App-MineralUtils'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our %SPEC;
 
@@ -58,14 +58,14 @@ my @magnesium_forms = (
 
     {
         name=>'mg-mg-ascorbate',
-        magnesium_ratio => 24.305/327.53, # 7.42%
-        summary => 'Magnesium ascorbate/pidolate (C11H13MgNO9), in milligrams',
+        magnesium_ratio => 24.305/374.54, # 6.49%
+        summary => 'Magnesium ascorbate (C12H14MgO12), in milligrams',
     },
 
     {
         name=>'mg-mg-pidolate',
-        magnesium_ratio => 24.305/327.53, # 7.42%
-        summary => 'Magnesium ascorbate/pidolate (C11H13MgNO9), in milligrams',
+        magnesium_ratio => 24.305/280.517, # 8.66%
+        summary => 'Magnesium pidolate (C10H12MgN2O6), in milligrams',
     },
 
     {
@@ -200,7 +200,7 @@ App::MineralUtils - Utilities related to mineral supplements
 
 =head1 VERSION
 
-This document describes version 0.006 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2021-12-09.
+This document describes version 0.007 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2021-12-11.
 
 =head1 DESCRIPTION
 
@@ -273,14 +273,14 @@ Result:
        summary => "Magnesium bisglycinate in NOW Foods supplement (C4H8MgN2O4, 70.5% pure, contains citric acid etc), in milligrams",
      },
      {
-       amount  => 13.5135135135135,
+       amount  => 15.3846153846154,
        unit    => "mg-mg-ascorbate",
-       summary => "Magnesium ascorbate/pidolate (C11H13MgNO9), in milligrams",
+       summary => "Magnesium ascorbate (C12H14MgO12), in milligrams",
      },
      {
-       amount  => 13.5135135135135,
+       amount  => 11.4942528735632,
        unit    => "mg-mg-pidolate",
-       summary => "Magnesium ascorbate/pidolate (C11H13MgNO9), in milligrams",
+       summary => "Magnesium pidolate (C10H12MgN2O6), in milligrams",
      },
      {
        amount  => 12.0481927710843,
@@ -300,12 +300,12 @@ Result:
    ],
    {
      "table.fields"        => ["amount", "unit", "summary"],
-     "table.field_aligns"  => ["number", "left", "left"],
      "table.field_formats" => [
-                                ["number", { thousands_sep => "", precision => 3 }],
+                                ["number", { precision => 3, thousands_sep => "" }],
                                 undef,
                                 undef,
                               ],
+     "table.field_aligns"  => ["number", "left", "left"],
    },
  ]
 
